Coco[-S]earch Terminal

### Project Not Indexed

Current project at `` is not indexed.

or run: `cocosearch index .`

### Index Warnings

### Available Indexes

### Repository

## Search Code

Language:
Symbol Type:
Advanced filters
Min score: 0.3 Limit: Hybrid search:
Auto = on for code identifiers only Dependencies:
Searching...
Loading dashboard data...

### Files Indexed

-
Total files

### Code Chunks

-
Searchable chunks

### Storage Size

-
Database size

### Last Updated

-
Index age

### Status

-
Index status

### Parse Health

-
File parse quality

## Language Distribution (Chunks)

## Symbol Types

## Grammar Distribution

## Parse Health by Language

Language | Files | OK | Partial | Error | No Grammar
--- | --- | --- | --- | --- | ---

## Parse Health by Grammar

Grammar handlers provide domain-specific chunking for specialized file formats. Health measures metadata extraction quality.

Grammar | Format | Files | Chunks | Recognized | Unrecognized | Health
--- | --- | --- | --- | --- | --- | ---

Dependency Graph Depth:
Loading graph...

Server Disconnected

The CocoSearch server has stopped. You can close this tab.

### Server Logs